@@ -15,3 +15,6 @@ DISPLAY_DATA = 1
 
 CHIP_SELECT_UNTOUCHED = 0
 CHIP_SELECT_TOGGLE_EVERY_BYTE = 1
+
+BACKLIGHT_IN_OUT = 1
+BACKLIGHT_PWM = 2
